
Installation
=============

You can install :py:mod:`pyplink` using either ``pip`` or ``conda``.

.. code-block:: bash

   # Using pip
   pip install pyplink


.. code-block:: bash

   # Using conda
   conda config --add channels http://statgen.org/wp-content/uploads/Softwares/pyplink
   conda install pyplink


To test the installation, run ``python`` and execute the following commands.

.. code-block:: python

   >>> import pyplink
   >>> pyplink.test()
   .............................................
   ----------------------------------------------------------------------
   Ran 45 tests in 0.343s

   OK
